#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_ABS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_ABS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/simd/abs.hpp>

#endif
